@@ -1364,124 +1364,6 @@ class DataReport(RepositoryItem):
         return self._data['front_page']
 
 
-class ImageHealth(object):
-
-    def __init__(self, rootfs_type, hwpack_type):
-        self.rootfs_type = rootfs_type
-        self.hwpack_type = hwpack_type
-
-    @models.permalink
-    def get_absolute_url(self):
-        return ("dashboard_app.views.image_status_detail", [
-            self.rootfs_type, self.hwpack_type])
-
-    def get_tests(self):
-        return Test.objects.filter(test_runs__in=self.get_test_runs()).distinct()
-
-    def current_health_for_test(self, test):
-        test_run = self.get_current_test_run(test)
-        test_results = test_run.test_results
-        fail_count = test_results.filter(
-            result=TestResult.RESULT_FAIL).count()
-        pass_count = test_results.filter(
-            result=TestResult.RESULT_PASS).count()
-        total_count = test_results.count()
-        return {
-            "test_run": test_run,
-            "total_count": total_count,
-            "fail_count": fail_count,
-            "pass_count": pass_count,
-            "other_count": total_count - (fail_count + pass_count),
-            "fail_percent": fail_count * 100.0 / total_count if total_count > 0 else None,
-        }
-    
-    def overall_health_for_test(self, test):
-        test_run_list = self.get_all_test_runs_for_test(test)
-        test_result_list = TestResult.objects.filter(test_run__in=test_run_list)
-        fail_result_list = test_result_list.filter(result=TestResult.RESULT_FAIL)
-        pass_result_list = test_result_list.filter(result=TestResult.RESULT_PASS)
-
-        total_count = test_result_list.count()
-        fail_count = fail_result_list.count()
-        pass_count = pass_result_list.count()
-        fail_percent = fail_count * 100.0 / total_count if total_count > 0 else None
-        return {
-            "total_count": total_count,
-            "total_run_count": test_run_list.count(),
-            "fail_count": fail_count,
-            "pass_count": pass_count,
-            "other_count": total_count - fail_count - pass_count,
-            "fail_percent": fail_percent,
-        }
-
-    def get_recent_test_runs(self, last_n_days=7 * 2):
-        until = datetime.datetime.now()
-        since = until - datetime.timedelta(days=last_n_days)
-        return self.get_test_runs(
-        ).select_related(
-            'denormalization',
-            'bundle',
-            'bundle__bundle_stream',
-            'test',
-        ).filter(
-            analyzer_assigned_date__range=(since, until)
-        ).order_by('-analyzer_assigned_date')
-
-    def get_chart_data(self):
-        return TestResult.objects.select_related(
-        ).filter(
-            test_run__in=[run.pk for run in self.get_recent_test_runs().only('id').order_by()]
-        ).values(
-            'test_run__analyzer_assigned_date'
-        ).extra(
-            select={'bucket': 'date(analyzer_assigned_date)'},
-        ).values(
-            'bucket', 'result'
-        ).annotate(
-            count=models.Count('result')
-        ).order_by('result')
-
-    def get_test_runs(self):
-        return TestRun.objects.select_related(
-        ).filter(
-            bundle__bundle_stream__pathname="/anonymous/lava-daily/"
-        ).filter(
-            attributes__name='rootfs.type'
-        ).filter(
-            attributes__value=self.rootfs_type
-        ).filter(
-            attributes__name='hwpack.type'
-        ).filter(
-            attributes__value=self.hwpack_type
-        )
-
-    def get_current_test_run(self, test):
-        return self.get_all_test_runs_for_test(test).order_by('-analyzer_assigned_date')[0]
-
-    def get_all_test_runs_for_test(self, test):
-        return self.get_test_runs().filter(test=test)
-
-    @classmethod
-    def get_rootfs_list(self):
-        rootfs_list = [
-            attr['value'] 
-            for attr in NamedAttribute.objects.filter(
-                name='rootfs.type').values('value').distinct()]
-        try:
-            rootfs_list.remove('android')
-        except ValueError:
-            pass
-        return rootfs_list
-
-    @classmethod
-    def get_hwpack_list(self):
-        hwpack_list = [
-            attr['value'] 
-            for attr in NamedAttribute.objects.filter(
-                name='hwpack.type').values('value').distinct()]
-        return hwpack_list
-
-
 class Tag(models.Model):
     """
     Tag used for marking test runs.
